@@ -23,6 +23,10 @@ class ModelPolicies:
     same model type, or dynamic, e.g. a different model type is returned depending on the current iteration.
     """
     STATIC_SVM_ENSEMBLE = StaticModelPolicy(ModelsCatalog.SVM_ENSEMBLE)
-    STATIC_SVM_GLOVE = StaticModelPolicy(ModelsCatalog.SVM_OVER_GLOVE)
+    STATIC_SVM_WORD_EMBEDDINGS = StaticModelPolicy(ModelsCatalog.SVM_OVER_WORD_EMBEDDINGS)
+    STATIC_SVM_GLOVE = StaticModelPolicy(ModelsCatalog.SVM_OVER_WORD_EMBEDDINGS)  # for backward compatibility
     STATIC_SVM_BOW = StaticModelPolicy(ModelsCatalog.SVM_OVER_BOW)
+    STATIC_NB_WORD_EMBEDDINGS = StaticModelPolicy(ModelsCatalog.NB_OVER_WORD_EMBEDDINGS)
+    STATIC_NB_BOW = StaticModelPolicy(ModelsCatalog.NB_OVER_BOW)
     STATIC_HF_BERT = StaticModelPolicy(ModelsCatalog.HF_BERT)
+    STATIC_HF_XLM_ROBERTA = StaticModelPolicy(ModelsCatalog.HF_XLM_ROBERTA)
