@@ -34,7 +34,8 @@ class TrainSetSelectorAllLabeled(TrainSetSelectorAPI):
     def __init__(self, data_access, background_jobs_manager, label_types=frozenset({LabelType.Standard})):
         super().__init__(data_access, background_jobs_manager, label_types=label_types)
 
-    def get_train_set(self, workspace_id, train_dataset_name, category_id) -> Sequence[TextElement]:
+    def get_train_set(self, workspace_id, train_dataset_name, category_id,
+                      category_name: str, category_description: str) -> Sequence[TextElement]:
         train_data, train_counts = self.get_data_and_counts_for_labeled(workspace_id, train_dataset_name, category_id,
                                                                         remove_duplicates=True)
         self.verify_all_labels_are_in_train(train_counts)
@@ -84,7 +85,8 @@ class TrainSetSelectorEnforcePositiveNegativeRatio(TrainSetSelectorAllLabeled):
         self.neg_label = LABEL_NEGATIVE
         self.pos_label = LABEL_POSITIVE
 
-    def get_train_set(self, workspace_id, train_dataset_name, category_id) -> Sequence[TextElement]:
+    def get_train_set(self, workspace_id, train_dataset_name, category_id,
+                      category_name: str, category_description: str) -> Sequence[TextElement]:
         train_data, train_counts = self.get_data_and_counts_for_labeled(workspace_id, train_dataset_name, category_id,
                                                                         remove_duplicates=True)
         current_neg_count = train_counts.get(self.neg_label, 0)
